"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const parseLineNumberRange_1 = require("./parseLineNumberRange");
const highlightCode_1 = require("./highlightCode");
const addLineNumbers_1 = require("./addLineNumbers");
const Languages = {
    html: "HTML",
    xml: "XML",
    svg: "SVG",
    mathml: "MathML",
    css: "CSS",
    clike: "C-like",
    js: "JavaScript",
    abap: "ABAP",
    abnf: "Augmented Backus–Naur form",
    apacheconf: "Apache Configuration",
    apl: "APL",
    arff: "ARFF",
    asciidoc: "AsciiDoc",
    adoc: "AsciiDoc",
    asm6502: "6502 Assembly",
    aspnet: "ASP.NET (C#)",
    autohotkey: "AutoHotkey",
    autoit: "AutoIt",
    shell: "Bash",
    basic: "BASIC",
    bnf: "Backus–Naur form",
    rbnf: "Routing Backus–Naur form",
    csharp: "C#",
    dotnet: "C#",
    cpp: "C++",
    cil: "CIL",
    coffee: "CoffeeScript",
    cmake: "CMake",
    csp: "Content-Security-Policy",
    "css-extras": "CSS Extras",
    django: "Django/Jinja2",
    jinja2: "Django/Jinja2",
    dockerfile: "Docker",
    ebnf: "Extended Backus–Naur form",
    ejs: "EJS",
    erb: "ERB",
    fsharp: "F#",
    gcode: "G-code",
    gedcom: "GEDCOM",
    glsl: "GLSL",
    gml: "GameMaker Language",
    gamemakerlanguage: "GameMaker Language",
    graphql: "GraphQL",
    hs: "Haskell",
    hcl: "HCL",
    http: "HTTP",
    hpkp: "HTTP Public-Key-Pins",
    hsts: "HTTP Strict-Transport-Security",
    ichigojam: "IchigoJam",
    inform7: "Inform 7",
    javadoc: "JavaDoc",
    javadoclike: "JavaDoc-like",
    javastacktrace: "Java stack trace",
    jsdoc: "JSDoc",
    "js-extras": "JS Extras",
    json: "JSON",
    jsonp: "JSONP",
    json5: "JSON5",
    latex: "LaTeX",
    tex: "TeX",
    context: "ConTeXt",
    emacs: "Lisp",
    elisp: "Lisp",
    "emacs-lisp": "Lisp",
    lolcode: "LOLCODE",
    md: "Markdown",
    "markup-templating": "Markup templating",
    matlab: "MATLAB",
    mel: "MEL",
    n1ql: "N1QL",
    n4js: "N4JS",
    n4jsd: "N4JS",
    "nand2tetris-hdl": "Nand To Tetris HDL",
    nasm: "NASM",
    nginx: "nginx",
    nsis: "NSIS",
    objectivec: "Objective-C",
    ocaml: "OCaml",
    opencl: "OpenCL",
    parigp: "PARI/GP",
    objectpascal: "Object Pascal",
    php: "PHP",
    phpdoc: "PHPDoc",
    "php-extras": "PHP Extras",
    plsql: "PL/SQL",
    powershell: "PowerShell",
    properties: ".properties",
    protobuf: "Protocol Buffers",
    py: "Python",
    q: "Q (kdb+ database)",
    jsx: "React JSX",
    tsx: "React TSX",
    renpy: "Ren'py",
    rest: "reST (reStructuredText)",
    rb: "Ruby",
    sas: "SAS",
    sass: "Sass (Sass)",
    scss: "Sass (Scss)",
    sql: "SQL",
    soy: "Soy (Closure Template)",
    tap: "TAP",
    toml: "TOML",
    tt2: "Template Toolkit 2",
    ts: "TypeScript",
    "t4-cs": "T4 Text Templates (C#)",
    t4: "T4 Text Templates (C#)",
    "t4-vb": "T4 Text Templates (VB)",
    "t4-templating": "T4 templating",
    vbnet: "VB.Net",
    vhdl: "VHDL",
    vim: "vim",
    "visual-basic": "Visual Basic",
    vb: "Visual Basic",
    wasm: "WebAssembly",
    wiki: "Wiki markup",
    xeoracube: "XeoraCube",
    xojo: "Xojo (REALbasic)",
    xquery: "XQuery",
    yaml: "YAML",
    yml: "YAML"
};
function normalizeLanguage(language, aliases) {
    const lower = language.toLowerCase();
    return aliases[lower] || lower;
}
module.exports = function (node, options) {
    const { markdownAST } = node;
    const { classPrefix = "language-", inlineCodeMarker = null, aliases = {}, noInlineHighlight = false, showLineNumbers: showLineNumbersGlobal = false } = options;
    unist_util_visit_1.default(markdownAST, "code", (node) => {
        let language = node.lang;
        let { splitLanguage, highlightLines, showLineNumbersLocal } = parseLineNumberRange_1.parseLineNumberRange(language);
        const showLineNumbers = showLineNumbersLocal || showLineNumbersGlobal;
        language = splitLanguage;
        // PrismJS's theme styles are targeting pre[class*="language-"]
        // to apply its styles. We do the same here so that users
        // can apply a PrismJS theme and get the expected, ready-to-use
        // outcome without any additional CSS.
        //
        // @see https://github.com/PrismJS/prism/blob/1d5047df37aacc900f8270b1c6215028f6988eb1/themes/prism.css#L49-L54
        let languageName = "text";
        if (language) {
            languageName = normalizeLanguage(language, aliases);
        }
        const showLanguage = Languages[languageName] ||
            languageName.charAt(0).toUpperCase() + languageName.slice(1);
        // Allow users to specify a custom class prefix to avoid breaking
        // line highlights if Prism is required by any other code.
        // This supports custom user styling without causing Prism to
        // re-process our already-highlighted markup.
        // @see https://github.com/gatsbyjs/gatsby/issues/1486
        const className = `${classPrefix}${languageName}`;
        let numLinesStyle, numLinesClass, numLinesNumber;
        numLinesStyle = numLinesClass = numLinesNumber = "";
        if (showLineNumbers) {
            /*
            /numLinesStyle = ` style="counter-reset: linenumber ${numberLinesStartAt -
              1}"`;*/
            numLinesClass = " line-numbers";
            numLinesNumber = addLineNumbers_1.addLineNumbers(node.value);
        }
        // Replace the node with the markup we need to make
        // 100% width highlighted code lines work
        node.type = "html";
        let highlightClassName = "gatsby-highlight";
        if (highlightLines && highlightLines.length > 0) {
            highlightClassName += " has-highlighted-lines";
        }
        const code = highlightCode_1.highlightCode(languageName, node.value, highlightLines, noInlineHighlight);
        node.value = `
    <div class="${highlightClassName}" data-language="${languageName}">
      <pre${numLinesStyle} class="${className}${numLinesClass}"><code class="${className}">${code}${numLinesNumber}</code></pre>
      <span class="language-name">${showLanguage}</span>
    </div>
    `;
    });
    if (!noInlineHighlight) {
        unist_util_visit_1.default(markdownAST, "inlineCode", (node) => {
            let languageName = "text";
            if (inlineCodeMarker) {
                let [language, restOfValue] = node.value.split(`${inlineCodeMarker}`, 2);
                if (language && restOfValue) {
                    languageName = normalizeLanguage(language, aliases);
                    node.value = restOfValue;
                }
            }
            const className = `${classPrefix}${languageName}`;
            node.type = "html";
            node.value = `<code class="${className}">${highlightCode_1.highlightCode(languageName, node.value)}</code>`;
        });
    }
};
//# sourceMappingURL=index.js.map